package org.fax4j.bridge.email;

import javax.mail.Message;
import org.fax4j.FaxJob;
import org.fax4j.bridge.FaxBridge;

/**
 * This interface defines the email2fax capabilities of the fax bridge.<br>
 * Email based bridge would probably not have much information to provide the fax client
 * and therefore has email specific bridge capabilities.
 * <br>
 * Below table describes the configuration values relevant for this class.<br>
 * <b>Configuration:</b>
 * <table border="1">
 * 	<tr>
 * 		<td>Name</td>
 * 		<td>Description</td>
 * 		<td>Preconfigured Value</td>
 * 		<td>Default Value</td>
 * 		<td>Mandatory</td>
 * </tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.vendor.policy.class.name</td>
 * 		<td>The vendor policy class name.</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>false</td>
 * 	</tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.mail.message.parser.class.name</td>
 * 		<td>The mail message parser class name used to convert the mail message to fax job data.</td>
 * 		<td>org.fax4j.bridge.email.DefaultMailMessageParser</td>
 * 		<td>org.fax4j.bridge.email.DefaultMailMessageParser</td>
 * 		<td>false</td>
 * 	</tr>
 * </table>
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.02
 * @since	0.40.6
 */
public interface EMail2FaxBridge extends FaxBridge
{
	/**The mail message request parser class name*/
	public static final String MAIL_MESSAGE_PARSER_CLASS_NAME_PROPERTY_KEY="org.fax4j.bridge.mail.message.parser.class.name";

	/**
	 * This function will submit a new fax job.
	 * 
	 * @param	mailMessage
	 * 			The mail message holding the fax job information
	 * @return	The fax job
	 */
	public FaxJob submitFaxJob(Message mailMessage);
}