package org.fax4j.bridge.http;

import org.fax4j.FaxJob;
import org.fax4j.bridge.FaxBridge;
import org.fax4j.spi.http.HTTPRequest;

/**
 * This interface defines the http2fax capabilities of the fax bridge.<br>
 * HTTP based bridges should be accessed by web servers via http servlet or similar.
 * <br>
 * Below table describes the configuration values relevant for this class.<br>
 * <b>Configuration:</b>
 * <table border="1">
 * 	<tr>
 * 		<td>Name</td>
 * 		<td>Description</td>
 * 		<td>Preconfigured Value</td>
 * 		<td>Default Value</td>
 * 		<td>Mandatory</td>
 * </tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.vendor.policy.class.name</td>
 * 		<td>The vendor policy class name.</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>false</td>
 * 	</tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.http.request.parser.class.name</td>
 * 		<td>The HTTP request parser class name used to convert the HTTP request to fax job data.</td>
 * 		<td>org.fax4j.bridge.http.DefaultHTTPRequestParser</td>
 * 		<td>org.fax4j.bridge.http.DefaultHTTPRequestParser</td>
 * 		<td>false</td>
 * 	</tr>
 * </table>
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.40.6
 */
public interface HTTP2FaxBridge extends FaxBridge
{
	/**The HTTP request parser class name*/
	public static final String HTTP_REQUEST_PARSER_CLASS_NAME_PROPERTY_KEY="org.fax4j.bridge.http.request.parser.class.name";

	/**
	 * This function will submit a new fax job.
	 * 
	 * @param	request
	 * 			The HTTP request
	 * @return	The submitted fax job
	 */
	public FaxJob submitFaxJob(HTTPRequest request);
}