package org.fax4j.bridge.process;

import org.fax4j.FaxJob;
import org.fax4j.bridge.FaxBridge;

/**
 * This interface defines the process2fax capabilities of the fax bridge.<br>
 * Process based bridges can be exposed as standalone java applications.
 * <br>
 * Below table describes the configuration values relevant for this class.<br>
 * <b>Configuration:</b>
 * <table border="1">
 * 	<tr>
 * 		<td>Name</td>
 * 		<td>Description</td>
 * 		<td>Preconfigured Value</td>
 * 		<td>Default Value</td>
 * 		<td>Mandatory</td>
 * </tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.vendor.policy.class.name</td>
 * 		<td>The vendor policy class name.</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>false</td>
 * 	</tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.process.command.parser.class.name</td>
 * 		<td>The command line parser class name used to convert the command line arguments to fax job data.</td>
 * 		<td>org.fax4j.bridge.process.DefaultCommandLineArgumentsParser</td>
 * 		<td>org.fax4j.bridge.process.DefaultCommandLineArgumentsParser</td>
 * 		<td>false</td>
 * 	</tr>
 * </table>
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.40.6
 */
public interface Process2FaxBridge extends FaxBridge
{
	/**The command parser class name*/
	public static final String COMMAND_PARSER_CLASS_NAME_PROPERTY_KEY="org.fax4j.bridge.process.command.parser.class.name";

	/**
	 * This function will submit a new fax job.
	 * 
	 * @param	commandLineArguments
	 * 			The command line arguments
	 * @return	The submitted fax job
	 */
	public FaxJob submitFaxJob(String[] commandLineArguments);
}