package org.fax4j.util;

import org.fax4j.common.ProviderImplementation;
import org.fax4j.spi.FaxClientSpi;

/**
 * This class defines the basic common connection factory capabilities.
 * 
 * @param	<T>
 * 			The resource type
 * @param	<S> 
 * 			The SPI type 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.39a
 */
public interface ConnectionFactory<T,S extends FaxClientSpi> extends ProviderImplementation
{
	/**
	 * This function initializes the connection factory.
	 * 
	 * @param	faxClientSpi
	 * 			The fax client SPI
	 */
	public void initialize(S faxClientSpi);

	/**
	 * Creates and returns the connection to be used.
	 *  
	 * @return	The connection
	 */
	public Connection<T> createConnection();

	/**
	 * Releases the connection.
	 *  
	 * @param	connection
	 * 			The connection
	 */
	public void releaseConnection(Connection<T> connection);
}